package it.eng.spago.cms;

import java.util.List;

import it.eng.spago.cms.exceptions.OperationExecutionException;
import it.eng.spago.cms.operations.DeleteOperation;
import it.eng.spago.cms.operations.GetOperation;
import it.eng.spago.cms.operations.RestoreOperation;
import it.eng.spago.cms.operations.SearchOperation;
import it.eng.spago.cms.operations.SetOperation;

/**
 * Defines the methods to exec operation on the repository. SpagoCms configuration must contain 
 * the name of a class that implements this interface
 */
public interface IExecutionService {

	/**
	 * Execs a Set operation using a default user credentials
	 * @param setOp Configuration of the set operation
	 * @throws OperationExecutionException Throwing if an error occurs during the execution
	 */
	public void doSetOperation(SetOperation setOp) throws OperationExecutionException;
	/**
	 * Execs a Set operation using a specific user name and password
	 * @param setOp Configuration of the set operation
	 * @param user User name 
	 * @param password User Password
	 * @throws OperationExecutionException Throwing if an error occurs during the execution
	 */
	public void doSetOperation(SetOperation setOp, String userId, String password) throws OperationExecutionException;
	
	/**
	 * Execs a Get operation using a default user credentials
	 * @param getOp Configuration of the get operation
	 * @throws OperationExecutionException Throwing if an error occurs during the execution
	 */
	public CmsNode doGetOperation(GetOperation getOp) throws OperationExecutionException;
	/**
	 * Execs a get operation using a specific user name and password
	 * @param getOp Configuration of the get operation
	 * @param user User name 
	 * @param password User Password
	 * @throws OperationExecutionException Throwing if an error occurs during the execution
	 */
	public CmsNode doGetOperation(GetOperation getOp, String userId, String password) throws OperationExecutionException;
	
	/**
	 * Execs a restore operation using a default user credentials
	 * @param restOp Configuration of the restore operation
	 * @throws OperationExecutionException Throwing if an error occurs during the execution
	 */
	public void doRestoreOperation(RestoreOperation restOp) throws OperationExecutionException;
	/**
	 * Execs a restore operation using a specific user name and password
	 * @param restOp Configuration of the restore operation
	 * @param user User name 
	 * @param password User Password
	 * @throws OperationExecutionException Throwing if an error occurs during the execution
	 */
	public void doRestoreOperation(RestoreOperation restOp, String userId, String password) throws OperationExecutionException;
	
	/**
	 * Execs a delete operation using a default user credentials
	 * @param delOp Configuration of the delete operation
	 * @throws OperationExecutionException Throwing if an error occurs during the execution
	 */
	public void doDeleteOperation(DeleteOperation delOp) throws OperationExecutionException;
	/**
	 * Execs a delete operation using a specific user name and password
	 * @param delOp Configuration of the delete operation
	 * @param user User name 
	 * @param password User Password
	 * @throws OperationExecutionException Throwing if an error occurs during the execution
	 */
	public void doDeleteOperation(DeleteOperation delOp, String userId, String password) throws OperationExecutionException;
	
	/**
	 * Execs a Search operation using a default user credentials
	 * @param searchOp Configuration of the search operation
	 * @throws OperationExecutionException Throwing if an error occurs during the execution
	 */
	public List doSearchOperation(SearchOperation searchOp) throws OperationExecutionException;
	/**
	 * Execs a search operation using a specific user name and password
	 * @param searchOp Configuration of the search operation
	 * @param user User name 
	 * @param password User Password
	 * @throws OperationExecutionException Throwing if an error occurs during the execution
	 */
	public List doSearchOperation(SearchOperation searchOp, String userId, String password) throws OperationExecutionException;
	
	
	
}
